##  Q&A on detailed changes
Q: Why do we need to add a Platform Fact Sheet?
A: We added a Platform Fact Sheet because we understand that management does not think in business capabilities or applications but rather in platforms. This provides an easy way to digest Information Technology. CIOs need insight into the technologies, interfaces, and applications that support their platforms.
Example: [CIO.com![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.cio.com%2F "https://www.cio.com/") may publish an article about how a company adopts [Salesforce.com![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.salesforce.com%2F "https://www.salesforce.com/") as a strategic platform - in SAP LeanIX, we should reflect that language and give insight into the technologies, interfaces, etc., support the platform
We believe that leveraging Platforms will help EAs make a more significant business impact.
Q: Why do we need to introduce a singular Business Context Fact Sheet with various subtypes?
A: We want our Meta Model to be streamlined and easily explainable on one slide. We acknowledge that Processes, Value Streams, Business Products, and ESG Capabilities are all relevant. Introducing a single Business Context Fact Sheet with subtypes allows us to cover those topics without cluttering the Meta Model.
Q: Why do we introduce default recommendations for Microservices?
A: We believe that for advanced EA practices, it is crucial to have a straightforward way to include a layer beyond the logical application. We are introducing the Microservice subtype for the Application Fact Sheet to provide structured modeling standards and an appropriate licensing model for our customers who need visibility into Microservices in SAP LeanIX. The API subtype for the Interface Fact Sheet enables customers to model data flows between Microservices. We will provide this as an optional extension - carefully assess whether your environment (e.g., ServiceNow integration with the usage of Application Services) requires this.
Q: Why do we extend the subtypes for IT Components?
A: The IT Component Fact Sheet will now include additional ‘SaaS’, ‘IaaS', and 'PaaS’ subtypes to provide a more differentiated view of the different IT components.
